@@ -27,3 +27,21 @@ class AttemptLimitReached(Exception):
 
     def __str__(self):
         return repr(self.msg)
+
+
+class NoEntryPointGroupError(Exception):
+    """Exception when no entry_point_group has been set"""
+    def __init__(self, msg):
+        self.msg = msg
+
+    def __str__(self):
+        return repr(self.msg)
+
+
+class ResourceNotFoundError(Exception):
+    """Exception when no entry_point_group has been set"""
+    def __init__(self, msg):
+        self.msg = msg
+
+    def __str__(self):
+        return repr(self.msg)
